﻿using System;

using DevExpress.XtraEditors;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 빙 맵 키
        /// </summary>
        private string bingKey = "INPUT YOUR BING KEY";

        /// <summary>
        /// 패턴 배열
        /// </summary>
        private string[] patternArray = new string[]
        {
            "{D:1}°{CP}",
            "{CP}{D:6}°",
            "{D}°{M:2}\'{CP}",
            "{CP}{D}°{M:2}\'",
            "{D}°{M}\'{S:4}\'\'{CP}",            
            "{CP}{D}°{M}\'{S:4}\'\'",
            "Coordinates: {D}°{M}\'{S:2}\'\'{CP}"
        };

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.bingMapDataProvider.BingKey = this.bingKey;

            this.xCoordinatePatternComboBoxEdit.SelectedIndexChanged += xCoordinatePatternComboBoxEdit_SelectedIndexChanged;
            this.yCoordinatePatternComboBoxEdit.SelectedIndexChanged += yCoordinatePatternComboBoxEdit_SelectedIndexChanged;

            SetComboBoxEditData(this.xCoordinatePatternComboBoxEdit);
            SetComboBoxEditData(this.yCoordinatePatternComboBoxEdit);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region X 좌표 패턴 콤보 박스 에디터 선택 인덱스 변경시 처리하기 - xCoordinatePatternComboBoxEdit_SelectedIndexChanged(sender, e)

        /// <summary>
        /// X 좌표 패턴 콤보 박스 에디터 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void xCoordinatePatternComboBoxEdit_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.mapControl.NavigationPanelOptions.XCoordinatePattern = this.xCoordinatePatternComboBoxEdit.EditValue as string;
        }

        #endregion
        #region Y 좌표 패턴 콤보 박스 에디터 선택 인덱스 변경시 처리하기 - yCoordinatePatternComboBoxEdit_SelectedIndexChanged(sender, e)

        /// <summary>
        /// Y 좌표 패턴 콤보 박스 에디터 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void yCoordinatePatternComboBoxEdit_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.mapControl.NavigationPanelOptions.YCoordinatePattern = this.yCoordinatePatternComboBoxEdit.EditValue as string;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 콤보 박스 에디터 데이터 설정하기 - SetComboBoxEditData(comboBoxEdit)

        /// <summary>
        /// 콤보 박스 에디터 데이터 설정하기
        /// </summary>
        /// <param name="comboBoxEdit">콤보 박스 에디터</param>
        private void SetComboBoxEditData(ComboBoxEdit comboBoxEdit)
        {
            comboBoxEdit.Properties.Items.AddRange(this.patternArray);

            comboBoxEdit.EditValue = comboBoxEdit.Properties.Items[0];
        }

        #endregion
    }
}